Bti

pub struct Bti {
    pub iommu_id: Option<u32>,
    pub bti_id: Option<u32>,
    pub name: Option<String>,
    /* private fields */
}
Definition of a bus transaction initiator (bti) for a platform device node.

Fields

iommu_id: Option<u32>bti_id: Option<u32>name: Option<String>

Name that can be used to retrieve the bti using [fuchsia.hardware.platform.device/GetBtiByName]. It is valid for this to be empty, however the resource will only be able to be retrieved using [fuchsia.hardware.platform.device/GetBtiById].