#[repr(C)]pub struct UserspaceIrq {
pub irq: u32,
pub controller_id: u32,
}Fields
irq: u32The userspace irq number, unique to the interrupt controller driver that provides it.
controller_id: u32A unique identifier for the controller that provides this interrupt.